@@ -1,6 +1,6 @@
 __all__ = ["VERSION", "PACKAGE", "WEBSITE", "ICON_PATH", "PIXMAP_PATH", "UI_PATH", "BIN_DIR"]
 
-VERSION = "2.3"
+VERSION = "2.3.1"
 PACKAGE = "blueman"
 WEBSITE = "https://github.com/blueman-project/blueman"
 PREFIX = "/usr/local"
@@ -10,7 +10,7 @@ ICON_PATH = "/usr/local/share/icons"
 PIXMAP_PATH = "/usr/local/share/blueman/pixmaps"
 UI_PATH = "/usr/local/share/blueman/ui"
 DHCP_CONFIG_FILE = "/etc/dhcp3/dhcpd.conf"
-POLKIT = True
+POLKIT = False
 GETTEXT_PACKAGE = "blueman"
 RFCOMM_WATCHER_PATH = "/usr/local/libexec/blueman-rfcomm-watcher"
 
